// Generated by dts-bundle-generator v8.1.2

import { AxiosPromise } from 'axios';
import { ControlPosition, FilterSpecification, IControl, LngLat, Map as MaplibreMap, Map as maplibreMap, MapGeoJSONFeature, MapLayerEventType, PaddingOptions, PointLike, RequireAtLeastOne } from 'maplibre-gl';

export declare enum ThemeType {
	CHRISTMAS = "christmas",
	HALLOWEEN = "halloween",
	MAPPY_BEE = "mappyBee",
	MAPXUS = "mapxus",
	LANDS_D = "landsD",
	COMMON = "common",
	MAPXUS_V2 = "mapxus_v2"
}
export interface ISelectedBuildingBorderStyle {
	lineWidth?: number;
	lineColor?: string;
	lineOpacity?: number;
}
export interface IFloorsControlStyle {
	fontColor?: string;
	activeFontColor?: string;
	backgroundColor?: string;
	activeBackgroundColor?: string;
	itemSize?: number;
	itemCount?: number;
	defaultFolded?: boolean;
}
export declare enum FloorSwitchMode {
	SWITCHED_BY_BUILDING = 0,
	SWITCHED_BY_VENUE = 1
}
export interface IMapOption {
	map: MaplibreMap;
	appId: string;
	secret: string;
	enableFloorControl?: boolean;
	enableBuildingSelector?: boolean;
	/**
	 * @description 'venueId', 'buildingId', 'floorId', 'poiId' are mutually exclusive,
	 * the priority is: poiId > floorId > buildingId > venueId.
	 */
	venueId?: string;
	/**
	 * @description 'venueId', 'buildingId', 'floorId', 'poiId' are mutually exclusive,
	 * the priority is: poiId > floorId > buildingId > venueId.
	 */
	buildingId?: string;
	/**
	 * @description 'venueId', 'buildingId', 'floorId', 'poiId' are mutually exclusive,
	 * the priority is: poiId > floorId > buildingId > venueId.
	 */
	floorId?: string;
	/**
	 * @description Initialize the map with POI as the center point, use it with maplibregl.Map 'zoom' option.
	 * 'venueId', 'buildingId', 'floorId', 'poiId' are mutually exclusive,
	 * the priority is: poiId > floorId > buildingId > venueId.
	 */
	poiId?: string;
	hiddenOutdoor?: boolean;
	theme?: ThemeType;
	collapseCopyright?: boolean;
	selectedBuildingBorderStyle?: ISelectedBuildingBorderStyle;
	floorsControlStyle?: IFloorsControlStyle;
	/**
	 * @description Switch floors by venue/building, default by venue.
	 */
	floorSwitchMode?: FloorSwitchMode;
	/**
	 * @description Whether unselected buildings are masked, default is false.
	 */
	maskNonSelectedAreas?: boolean;
	/**
	 * @description Whether the boundary of the selected building fits the screen, default is false.
	 * Can only be used for 'floorId', 'buildingId' and 'venueId' initialization, not for 'poiId'.
	 * When it is true, the 'boundsPadding' option is valid, and the 'zoom' option of maplibregl.Map is invalid.
	 */
	fitBuildingBounds?: boolean;
	/**
	 * @description The amount of padding in pixels to add to the given bounds, default is 30.
	 * Requires 'fitBuildingBounds' to be 'true'.
	 * Parameter value ref to: https://maplibre.org/maplibre-gl-js/docs/API/types/maplibregl.PaddingOptions/
	 */
	boundsPadding?: number | RequireAtLeastOne<PaddingOptions>;
}
export type Listener = (param: Object) => any;
declare class DefinedEvent {
	private _type;
	private _target;
	constructor(type: string, data?: Object);
	get type(): string;
	set type(type: string);
	get target(): Evented;
	set target(target: Evented);
}
/**
 * Methods mixed in to other classes for event capabilities.
 *
 * @mixin Evented
 */
export declare class Evented {
	private _listeners;
	private _oneTimeListeners;
	private _eventedParent;
	private _eventedParentData;
	/**
	 * @description Register a new event listener
	 * @param type name of the event(a unique string)
	 * @param listener event handler, it will be called when the event is fired
	 */
	on(type: string, listener: Listener): this;
	/**
	 * @description Remove a registered event listener
	 * @param type name of the event
	 * @param listener event handler
	 */
	off(type: string, listener: Listener): this;
	/**
	 * Adds a listener that will be called only once to a specified event type.
	 *
	 * The listener will be called first time the event fires after the listener is registered.
	 *
	 * @param {string} type The event type to listen for.
	 * @param {Function} listener The function to be called when the event is fired the first time.
	 * @returns {Object} `this`
	 */
	once(type: string, listener: Listener): this;
	fire(event: DefinedEvent): this;
	/**
	 * Returns a true if this instance of Evented or any forwardeed instances of Evented have a listener for the specified type.
	 *
	 * @param {string} type The event type
	 * @returns {boolean} `true` if there is at least one registered listener for specified event type, `false` otherwise
	 * @private
	 */
	listens(type: string): boolean;
	/**
	 * Bubble all events fired by this instance of Evented to this parent instance of Evented.
	 *
	 * @returns {Object} `this`
	 * @private
	 */
	setEventedParent(parent: Evented, data?: Object | (() => Object)): this;
}
export interface IFloor {
	code: string | null;
	id: string | null;
	ordinal: string | null;
}
export declare class Indoor extends Evented {
	private _map;
	private _features;
	private _curBuildingId;
	private _curBuildingFeature;
	private _ordinal;
	private _floorId;
	private _floorName;
	private _enableSwitch;
	private _enableSwitchBuilding;
	private _isHiddenOutdoor;
	private _indoorLayers;
	private _hasCustomLevelFill;
	private _curVenueId;
	private _curVenueFeature;
	private _ordinalHistory;
	private _buildingHighlightStyle;
	private readonly _floorSwitchMode;
	private _maskNonSelectedAreas;
	private _isSelectBuildingByClickMap;
	private readonly _hiddenBuildings;
	private _lowerLayers;
	private _upperLayers;
	private _commonLayers;
	private _upperBuildingIds;
	private _lowerBuildingIds;
	private _upperLevelIds;
	private _lowerLevelIds;
	private _dispatch;
	private readonly _fitBuildingBounds;
	private readonly _boundsPadding;
	private readonly _isInitialIndoor;
	private _maplibreMapLoaded;
	private _indoorMapLoaded;
	constructor(props: {
		map: maplibreMap;
		isInitialIndoor: boolean;
		isHiddenOutdoor: boolean;
		floorSwitchMode: FloorSwitchMode;
		fitBuildingBounds: boolean;
		boundsPadding: number | RequireAtLeastOne<PaddingOptions>;
	});
	/**
	 * @description Turn on indoor-outdoor switching.
	 */
	enableSwitch(): this;
	/**
	 * @description Turn off indoor-outdoor switching.
	 */
	disableSwitch(): this;
	/**
	 * @description Turn on building-building switching.
	 */
	enableSwitchBuilding(): this;
	/**
	 * @description Turn off building-building switching.
	 */
	disableSwitchBuilding(): this;
	/**
	 * @description Get the current floor's information.
	 */
	get floor(): IFloor;
	/**
	 * @description Get the current building's information.
	 * @returns {MapGeoJSONFeature | null}
	 */
	get building(): MapGeoJSONFeature | null;
	/**
	 * @description Get the current venue's information.
	 * @returns {MapGeoJSONFeature | null}
	 */
	get venue(): MapGeoJSONFeature | null;
	/**
	 * @description Get the geo features of bbox.
	 */
	get features(): MapGeoJSONFeature[];
	/**
	 * @description Get specified feature of bbox by id.
	 * @deprecated Use 'getFeaturesById' instead.
	 * @param id
	 * @return {MapGeoJSONFeature | undefined}
	 */
	getFeature(id: string): MapGeoJSONFeature | undefined;
	/**
	 * @description Get features from bbox by id.
	 * @param id
	 */
	getFeaturesById(id: string): MapGeoJSONFeature[];
	/**
	 * @description Get level feature at the point
	 * @param point
	 * @return {MapGeoJSONFeature | null}
	 */
	getLevelByPoint(point: PointLike): MapGeoJSONFeature | null;
	/**
	 * @description Map pan to the building center and select the building.
	 * @param buildingId
	 * @param floorId
	 * @param callback
	 */
	panToBuilding(buildingId: string, floorId?: string, callback?: (feature: MapGeoJSONFeature) => void): Promise<void>;
	/**
	 * @description Switch floor by ordinal.
	 * @param ordinal
	 */
	switchFloorByOrdinal(ordinal: string): void;
	/**
	 * @description Hide the outdoor layer.
	 * @param isHiddenOutdoor
	 */
	hiddenOutdoorLayer(isHiddenOutdoor: boolean): void;
	/**
	 * @description Update map layout.
	 */
	updateLayers(): void;
	updateRendering(): void;
	/**
	 * @description Filter indoor layers.
	 */
	setFloorsFilter(): void;
	/**
	 * @description Set the style of SelectedBuildingBorder.
	 * @param style {ISelectedBuildingBorderStyle | null}
	 */
	setSelectedBuildingBorderStyle(style: ISelectedBuildingBorderStyle | null): void;
	/**
	 * @description Set whether to cover the unselected venues/buildings.
	 * @param mask Default is false.
	 */
	setMaskNonSelectedAreas(mask: boolean): void;
	/**
	 * @description Listen for the indoor map state, including the changes of venue, building and floor.
	 * @param listener
	 */
	onMapChange(listener: (params: {
		venue: MapGeoJSONFeature | null;
		building: MapGeoJSONFeature | null;
		floor: IFloor;
	}) => void): {
		unsubscribe: VoidFunction;
	};
	/**
	 * @description Select a building feature
	 * @param feature {MapGeoJSONFeature | null}
	 * @param floorId {string}
	 */
	selectBuilding(feature?: MapGeoJSONFeature | null, floorId?: string): void;
	private _getBuildingByPoint;
	private _getConditionsExpression;
	private _loadData;
	private _init;
	private _filter;
	private _clear;
	private _updateFilter;
	private _setPoiTextColor;
	private _addTextHaloColor;
	private _getFeatures;
	private _getBuildingFloorByOrdinal;
	private _getBuildingFloorByFloorId;
	private _getBuildingInitFloor;
	private _isNotCurrentFeature;
	private _setOutdoorLayersHidden;
	private _addCustomLevelFillLayer;
	private _setIndoorState;
	private _setBuildingLineOpacity;
	private _addBuildingHighlightLayer;
	private _filterBuildingHighlight;
	private _addHiddenBuilding;
	private _deleteHiddenBuilding;
	private _setDisplayLevels;
	private _configMaskVenueMode;
	private _configMaskBuildingMode;
	private _configVenueMode;
	private _configBuildingMode;
	private _getVenueOriginOrdinal;
	private _getBuildingOriginOrdinal;
	private _isVenueMode;
	private _setVenueOrdinalHistory;
	private _getVenueOrdinalHistory;
	private _setBuildingOrdinalHistory;
	private _getBuildingOrdinalHistory;
	private _getVenuesOfBbox;
	private _getBuildingsOfBbox;
	private _copyOverlapLayers;
	private _layerBuildings;
	private _addBuildingToUpper;
	private _deleteBuildingFromUpper;
	private _addBuildingToLower;
	private _deleteBuildingFromLower;
	private _addLevelToUpper;
	private _deleteLevelFromUpper;
	private _addLevelToLower;
	private _deleteLevelFromLower;
	private _filterGroupLayers;
	private _filterRestOriginLayers;
	private _getNewFilter;
	private static isFilterHasBeenReset;
}
export interface IPoiEvent {
	coordinate: LngLat;
	poi: MapGeoJSONFeature;
	building: MapGeoJSONFeature | null;
	venue: MapGeoJSONFeature | null;
	floor: IFloor;
}
export interface IPointEvent {
	coordinate: LngLat;
	point: PointLike;
}
export interface IMapClickEvent {
	coordinate: LngLat;
	building: MapGeoJSONFeature | null;
	venue: MapGeoJSONFeature | null;
	floor: IFloor;
}
export declare class Map extends Evented {
	private _map;
	private _indoor;
	private _floorsControl;
	private _buildingFilterControl;
	private _enableFloorControl;
	private _enableBuildingSelector;
	private _poi;
	private _initialHiddenLayers;
	private _attributionControl;
	private _dispatch;
	constructor(option: IMapOption);
	/**
	 * @description This function will be called once the indoor source loaded.
	 * @param callback
	 */
	renderComplete(callback: VoidFunction): void;
	/**
	 * @description Get map indoor instance.
	 */
	getIndoor(): Indoor;
	/**
	 * @description Get maplibre map instance.
	 */
	getMap(): MaplibreMap;
	/**
	 * @description Translate POI name to the specified language.
	 * @param language Window.navigator.language.
	 */
	transformPoiTextFieldLanguage(language: string): void;
	/**
	 * @description Turn on indoor-outdoor switching.
	 */
	enableSwitch(): this;
	/**
	 * @description Turn off indoor-outdoor switching.
	 */
	disableSwitch(): this;
	/**
	 * @description Turn on building-building switching.
	 */
	enableSwitchBuilding(): this;
	/**
	 * @description Turn off building-building switching.
	 */
	disableSwitchBuilding(): this;
	/**
	 * @description Set outdoor layer to be shown or hidden.
	 * @param isHidden True is hidden, false is shown.
	 */
	setOutdoorLayerHidden(isHidden: boolean): void;
	/**
	 * @description Get current selected floor info.
	 * @return {IFloor | null}
	 */
	get floor(): IFloor | null;
	/**
	 * @description Get current selected building info.
	 * @return {MapGeoJSONFeature | null}
	 */
	get building(): MapGeoJSONFeature | null;
	/**
	 * @description Get current selected venue info.
	 * @return {MapGeoJSONFeature | null}
	 */
	get venue(): MapGeoJSONFeature | null;
	/**
	 * @description Get feature in bbox by id.
	 * @deprecated Use 'getFeaturesById' instead.
	 * @param id
	 * @return {MapGeoJSONFeature | undefined}
	 */
	getFeature(id: string): MapGeoJSONFeature | undefined;
	/**
	 * @description Get features from bbox by coordinates [and ordinal].
	 * @param coordinates
	 * @param ordinal
	 */
	getIndoorFeaturesByCoordinates(coordinates: {
		lng: number;
		lat: number;
	}, ordinal?: number): {
		venue: MapGeoJSONFeature;
		building: MapGeoJSONFeature;
		level: MapGeoJSONFeature;
	};
	/**
	 * @description Get features from bbox by id. One id may correspond to multiple features.
	 * @param id
	 */
	getFeaturesById(id: string): MapGeoJSONFeature[];
	/**
	 * @description Select floor by id.
	 * @param floorId
	 * @param callback Called after floor has been selected.
	 */
	selectFloorById(floorId: string, callback?: VoidFunction): Promise<void>;
	/**
	 * @description Select building by id.
	 * @param buildingId
	 * @param callback Called after building has been selected
	 */
	selectBuildingById(buildingId: string, callback?: VoidFunction): Promise<void>;
	/**
	 * @description Select or exit venue by id.
	 * @param venueId 'venueId' can be string or null. Exit indoors if venueId is null.
	 * @param callback Called after venue has been selected.
	 */
	selectVenueById(venueId: string | null, callback?: VoidFunction): Promise<void>;
	/**
	 * @description Listen for mouse click events on the map.
	 * @param listener
	 */
	onMapClickListener(listener: (event: IMapClickEvent) => void): {
		unsubscribe: VoidFunction;
	};
	/**
	 * @description Listen for mouse click events on indoor POI
	 * @param listener
	 */
	onPoiClickListener(listener: (param: IPoiEvent) => void): {
		unsubscribe: VoidFunction;
	};
	/**
	 * @description Listen for mouse click events at a point.
	 * @param listener
	 */
	onPointClickListener(listener: (result: IPointEvent) => void): {
		unsubscribe: VoidFunction;
	};
	/**
	 * @description Listen for the indoor map status, including the changes of venue, building and floor.
	 * @param listener
	 */
	onMapChangeListener(listener: (params: {
		venue: MapGeoJSONFeature | null;
		building: MapGeoJSONFeature | null;
		floor: IFloor;
	}) => void): {
		unsubscribe: VoidFunction;
	};
	/**
	 * @description Hide the FloorControl.
	 */
	disableFloorControl(): this;
	/**
	 * @description Show the FloorControl.
	 * @param position
	 */
	enableFloorControl(position?: ControlPosition): this;
	/**
	 * @description Hide the BuildingSelector.
	 */
	disableBuildingSelector(): this;
	/**
	 * @description Show the BuildingSelector.
	 * @param position
	 */
	enableBuildingSelector(position?: ControlPosition): this;
	/**
	 * @description Switch the map style
	 * @param theme ThemeType | string(customized map style file name)
	 */
	switchTheme(theme: string): void;
	/**
	 * @description Set the floorsControl's style.
	 * @param style
	 */
	setFloorsControlStyle(style: IFloorsControlStyle): this;
	/**
	 * @description Set the SelectedBuildingBorder's style
	 * @param style {ISelectedBuildingBorderStyle | null}
	 */
	setSelectedBuildingBorderStyle(style: ISelectedBuildingBorderStyle | null): this;
	private static _getThemeStyleName;
	private _setIndoorFilter;
	private _setStyle;
	private _addControl;
	private _selectPoiById;
	private _getBuildingIdByVenueId;
	private _tilesRequestTransform;
	private _checkMapZoom;
	private _setMapStyle;
	private _clickEventsDispatcher;
	private _hideIndoorLayers;
	private _showIndoorLayers;
	private _updatePermission;
}
export type TAnchorPosition = "center" | "left" | "right" | "top" | "bottom" | "top-left" | "top-right" | "bottom-left" | "bottom-right";
export declare class Marker {
	private readonly _maplibreMap;
	private readonly _layerId;
	private readonly _sourceId;
	private _imageName;
	private _imageSize;
	private _iconAnchor;
	constructor(maplibreMap: MaplibreMap);
	/**
	 * @description Set marker by sprite name.
	 * This method must be called after map style loaded if you set an external URL.
	 * @param icon Sprite name in map style or the image url, png format.
	 * @param callback Called when the image(from an external URL) has loaded
	 * or with an error argument if there is an error.
	 */
	setIconImage(icon: string, callback?: VoidFunction): void;
	/**
	 * @description Set marker by image url.
	 * @deprecated Use 'setIconImage' instead.
	 * @param imageUrl Network url, png format.
	 */
	setIconImageUrl(imageUrl: string): void;
	/**
	 * @description Set marker image size.
	 * @param imageScale Default is 1.
	 */
	setIconSize(imageScale: number): void;
	/**
	 * @description Set marker image anchor. Part of the icon placed closest to the anchor.
	 * @param anchor
	 */
	setIconAnchor(anchor: TAnchorPosition): void;
	/**
	 * @description Marker layer id getter.
	 */
	get layerId(): string;
	/**
	 * @description Marker source id getter.
	 */
	get sourceId(): string;
	/**
	 * @description Create marker[s] source and layer.
	 * @param array Coordinate and properties arrays of marker[s].
	 */
	create(array: Array<{
		lngLat: [
			number,
			number
		];
		properties?: {
			[k: string]: string;
		};
	}>): void;
	/**
	 * @description Remove marker[s] layer and source.
	 */
	remove(): void;
	/**
	 * @description Add marker event listener.
	 * @param eventKey
	 * @param callback
	 */
	onEventListener(eventKey: keyof MapLayerEventType, callback: (marker: MapGeoJSONFeature) => void): {
		offEventListener: VoidFunction;
	};
	/**
	 * @description Filter marker by custom properties.
	 * @param filterExpression A expression specifying conditions on source features.
	 * Only features that match the filter are displayed. Refer:
	 * https://maplibre.org/maplibre-style-spec/expressions/
	 */
	setFilter(filterExpression: FilterSpecification): void;
	/**
	 * @description Filter marker by venueId and ordinal.
	 * Required 'venueId' and 'ordinal' in properties.
	 * Markers not matched 'venueId' and 'ordinal' would be hidden;
	 * Outdoor markers always are shown.
	 * @param venueId {string | null | undefined} null | undefined will be treated as ''.
	 * @param ordinal {string | null | undefined} null | undefined will be treated as ''.
	 */
	setFilterByVenue(venueId: string | null | undefined, ordinal: string | null | undefined): void;
	/**
	 * @description Filter marker by buildingId and ordinal.
	 * Required 'buildingId' and 'ordinal' in properties.
	 * Markers not matched 'buildingId' and 'ordinal' would be hidden;
	 * Outdoor markers always are shown.
	 * @param buildingId {string | null | undefined} null | undefined will be treated as ''.
	 * @param ordinal {string | null | undefined} null | undefined will be treated as ''.
	 */
	setFilterByBuilding(buildingId: string | null | undefined, ordinal: string | null | undefined): void;
	/**
	 * @description Set marker's icon-opacity by custom properties.
	 * @param filterExpression A expression specifying conditions on source features.
	 * Only features that match the filter are displayed. Refer:
	 * https://maplibre.org/maplibre-style-spec/expressions/
	 */
	setOpacity(filterExpression: FilterSpecification): void;
	/**
	 * @description Set marker's icon-opacity by venueId and ordinal.
	 * Required 'venueId' and 'ordinal' in properties.
	 * Opacities of markers matched 'venueId' and 'ordinal' are 1, others are 0.5.
	 * Outdoor markers' opacity always are 1.
	 * @param venueId {string | null | undefined} null | undefined will be treated as ''.
	 * @param ordinal {string | null | undefined} null | undefined will be treated as ''.
	 */
	setOpacityByVenue(venueId: string | null | undefined, ordinal: string | null | undefined): void;
	/**
	 * @description Set marker's icon-opacity by buildingId and ordinal.
	 * Required 'buildingId' and 'ordinal' in properties.
	 * Opacities of markers matched 'buildingId' and 'ordinal' are 1, others are 0.5.
	 * Outdoor markers' opacity always are 1.
	 * @param buildingId {string | null | undefined} null | undefined will be treated as ''.
	 * @param ordinal {string | null | undefined} null | undefined will be treated as ''.
	 */
	setOpacityByBuilding(buildingId: string | null | undefined, ordinal: string | null | undefined): void;
	private _createIconFeature;
	private _addIconSource;
	private _addIconLayer;
	private _handleEventListener;
}
export declare class Poi {
	private _map;
	private _layerIds;
	private _dispatch;
	constructor(map: MaplibreMap);
	/**
	 * @description Listen for POI click events.
	 * @param listener
	 */
	onPoiClick(listener: (param: IPoiEvent) => void): {
		unsubscribe: VoidFunction;
	};
	private _bindEvents;
	private _init;
	private _initPoiClick;
	private _getFloorDataByFloorId;
}
export declare class FloorsControl implements IControl {
	private _container;
	private _indoor;
	private _position;
	private _floorNames;
	private _ordinals;
	private _buildingId;
	private _selectorStyle;
	private _$innerFloors;
	private _$activeFloor;
	private _centerSelectorIdx;
	private _lastNormalScrollableIdx;
	private _$arrowBtnUp;
	private _$arrowBtnDown;
	private _maxScrollTop;
	private _$selectorExpanded;
	private _$selectorFolded;
	private _componentDidMount;
	private _isShown;
	constructor(indoor: Indoor);
	onAdd(): HTMLElement;
	onRemove(): void;
	getDefaultPosition(): ControlPosition;
	switchByOrdinal(ordinal: string, callback?: VoidFunction): void;
	setVisibility(visible: boolean): void;
	setPosition(position: ControlPosition): void;
	setStyle(style: Partial<IFloorsControlStyle> | null): void;
	private _bindEvents;
	private _clearData;
	private _render;
	private _hide;
	private _show;
	private _createSelector;
	private _$expandedSelector;
	private _$foldedSelector;
	private _clearSelector;
	private _$createScrollButton;
	private _$createFloors;
	private _updateSelectorStatus;
	private _resetArrowBtnStatus;
	private _resetActiveFloor;
	private _scrollCenterActiveFloor;
	private _getScrollTop;
	private _handleScroll;
	private _expandSelector;
}
export declare class BuildingFilterControl implements IControl {
	private _map;
	private _indoor;
	private _buildingId;
	private _features;
	private _container;
	private _buildingNameLayout;
	private _buildingNameList;
	private _enableBuildingSelector;
	private readonly _position;
	constructor(map: Map, position?: ControlPosition);
	onAdd(map: MaplibreMap): HTMLElement;
	onRemove(): void;
	get position(): ControlPosition;
	get enabled(): boolean;
	setLayoutHidden(isHidden: boolean): void;
	moveBuildingFilter(from: ControlPosition, to: ControlPosition): void;
	private _loadData;
	private _init;
	private _refresh;
	private _select;
	private _load;
	private _buildingFilterIconCreate;
	private _buildingNameListCreate;
	private _buildingNameListUpdate;
	private _buildingNameListClean;
	private _buildingNameListHeight;
	private _buildingNameCreate;
	private _toggleList;
	private _buildingNameClickEvent;
	private _buildingToggleListEvent;
	private _$showLayout;
	private _$hideLayout;
}
export interface IResponse<T> {
	code: number;
	message: string;
	result: T;
}
export type IPresetLanguage = "en" | "zh-Hans" | "zh-Hant" | "ja" | "ko";
export interface IMultiLangName extends Partial<Record<IPresetLanguage, string>> {
	default: string;
}
export type IMultiLangAddress = Record<keyof IMultiLangName, {
	housenumber: string;
	street: string;
}>;
export interface IBbox {
	maxLat: number;
	maxLon: number;
	minLat: number;
	minLon: number;
}
export interface ILabelCenter {
	lat: number;
	lon: number;
}
export interface IBuildingFloor {
	id: string;
	code: string;
	ordinal: number;
	visualMap: boolean;
	signalMap: boolean;
}
export interface IBuilding {
	address: IMultiLangAddress;
	bbox: IBbox;
	buildingId: string;
	buildingOutlineId: number;
	city?: string;
	country: string;
	floors: IBuildingFloor[];
	groundFloor: string;
	isPrivate: "yes" | "no";
	labelCenter: ILabelCenter;
	name: IMultiLangName;
	organization: string;
	region: string;
	signalMap: boolean;
	type: string;
	venueId: string;
	venueName: IMultiLangName;
	defaultFloor?: string;
}
export interface IEntityPoint {
	type: string;
	coordinates: [
		number,
		number
	];
}
export interface IVenueInlineBuilding {
	id: string;
	name: IMultiLangName;
	buildingOutlineId: number;
	point: IEntityPoint;
	floors: IBuildingFloor[];
	visualMap: boolean;
	signalMap: boolean;
}
export interface IVenue {
	id: string;
	name: IMultiLangName;
	address: IMultiLangAddress;
	type: string;
	venueOutlineId: number;
	bbox: IBbox;
	labelCenter: ILabelCenter;
	point: IEntityPoint;
	organization: string[];
	restricted: boolean;
	owner: string;
	country: string;
	region: string;
	buildings: IVenueInlineBuilding[];
	visualMap: boolean;
	signalMap: boolean;
	defaultBuilding?: string;
}
export interface IResponseVenues {
	venues: IVenue[];
	total: number;
}
export declare class VenuesService {
	private _api;
	private _request;
	constructor();
	/**
	 * @description Search venues by ids.
	 * @param ids The number of IDs cannot exceed 10.
	 */
	searchByIds(ids: string | string[]): AxiosPromise<IResponse<IResponseVenues>>;
	/**
	 * @description Search venues by center and distance.
	 * @param keywords
	 * @param center
	 * @param distance Radius from center, unit is kilometers.
	 * @param offset The maximum value is 100, default is 10.
	 * @param page Default is 1.
	 */
	searchByDistance(keywords: string, center: [
		number,
		number
	], distance: number, offset?: number, page?: number): AxiosPromise<IResponse<IResponseVenues>>;
	/**
	 * @description Search venues in specified bbox.
	 * @param keywords
	 * @param bbox Rectangular area, [minLon, minLat, maxLon, maxLat].
	 * @param offset The maximum value is 100, default is 10.
	 * @param page Default is 1.
	 */
	searchByBbox(keywords: string, bbox: [
		number,
		number,
		number,
		number
	], offset?: number, page?: number): AxiosPromise<IResponse<IResponseVenues>>;
	/**
	 * @description Search venues by global.
	 * @param keywords
	 * @param offset The maximum value is 100, default is 10.
	 * @param page Default is 1.
	 */
	searchByGlobal(keywords: string, offset?: number, page?: number): AxiosPromise<IResponse<IResponseVenues>>;
	private _changedRes;
}
export interface IResponseBuildings {
	buildings: IBuilding[];
	total: number;
}
export declare class BuildingsService {
	private _api;
	private _request;
	constructor();
	/**
	 * @description Search buildings by id[s].
	 * @param ids Single id string or id string array. The number of IDs cannot exceed 10.
	 */
	searchByIds(ids: string | string[]): AxiosPromise<IResponse<IResponseBuildings>>;
	/**
	 * @description Search buildings by center and distance.
	 * @param keywords
	 * @param center
	 * @param distance Radius from center, unit is kilometers.
	 * @param offset The maximum value is 100, default is 10.
	 * @param page Default is 1.
	 */
	searchByDistance(keywords: string, center: number[], distance: number, offset?: number, page?: number): AxiosPromise<IResponse<IResponseBuildings>>;
	/**
	 * @description Search buildings in specified bbox.
	 * @param keywords
	 * @param bbox Rectangular area, [minLon, minLat, maxLon, maxLat].
	 * @param offset The maximum value is 100, default is 10.
	 * @param page Default is 1.
	 */
	searchByBbox(keywords: string, bbox: number[], offset?: number, page?: number): AxiosPromise<IResponse<IResponseBuildings>>;
	/**
	 * @description Search buildings global.
	 * @param keywords
	 * @param offset The maximum value is 100, default is 10.
	 * @param page Default is 1.
	 */
	searchByGlobal(keywords: string, offset?: number, page?: number): AxiosPromise<IResponse<IResponseBuildings>>;
	/**
	 * @description Search building by floor id.
	 * @param floorId
	 */
	searchByFloorId(floorId: string): AxiosPromise<IResponse<IResponseBuildings>>;
	private _changedRes;
}
export interface ILocation {
	lat: number;
	lon: number;
}
export interface IPoi {
	accessibilityDetail: object;
	buildingId: string;
	category: string[];
	floor: string;
	floorId: string;
	id: string;
	location: ILocation;
	name: IMultiLangName;
	osmRefId: number;
	poiId: string;
	venueId: string;
	description?: string;
	email?: string;
	openingHours?: string;
	phone?: string;
	website?: string;
}
export interface IResponsePois {
	pois: IPoi[];
	total: number;
}
export declare enum DistanceSearchType {
	POINT = "Point",
	POLYGON = "Polygon",
	GATE = "Gate"
}
export interface IPoiCategory {
	category: string;
	description: string;
	id: string;
	title: Partial<Record<keyof IMultiLangName, string>>;
}
export interface IOrientationPoi {
	angle: number;
	buildingId: string;
	category: string[];
	distance: number;
	distanceSource: string;
	floor: string;
	floorId: string;
	id: string;
	location: ILocation;
	name: IMultiLangName;
	osmRefId: number;
	poiId: string;
}
export declare class PoisService {
	private _api;
	private _categoriesV2;
	private _request;
	constructor();
	/**
	 * @description Search POIs by id[s].
	 * @param ids Single id string or id string array. The number of IDs cannot exceed 100.
	 */
	searchByIds(ids: string | string[]): AxiosPromise<IResponse<IResponsePois>>;
	/**
	 * @description Search POIs by radius distance of the center point.
	 * @param category
	 * @param center
	 * @param distance Radius from center, unit is meter, cannot exceed 10,000.
	 * @param offset The maximum value is 100, default is 10.
	 * @param page Default is 1.
	 */
	searchByDistance(category: string, center: number[], distance: number, offset?: number, page?: number): AxiosPromise<IResponse<IResponsePois>>;
	/**
	 * @description Search POIs in a bbox.
	 * @param keywords
	 * @param bbox Rectangular area, [minLon, minLat, maxLon, maxLat].
	 * @param offset The maximum value is 100, default is 10.
	 * @param page Default is 1.
	 */
	searchByBbox(keywords: string, bbox: number[], offset?: number, page?: number): AxiosPromise<IResponse<IResponsePois>>;
	/**
	 * @description Search POIs of a building.
	 * @param keywords
	 * @param buildingId
	 * @param offset The maximum value is 100, default is 10.
	 * @param page Default is 1.
	 */
	searchByBuildingId(keywords: string, buildingId: string, offset?: number, page?: number): AxiosPromise<IResponse<IResponsePois>>;
	/**
	 * @description Search POIs of a venue.
	 * @param keywords
	 * @param venueId
	 * @param offset
	 * @param page
	 */
	searchByVenueId(keywords: string, venueId: string, offset?: number, page?: number): AxiosPromise<IResponse<IResponsePois>>;
	/**
	 * @description Search poi categories by venue id, building id, or floor id.
	 * Search scope priority: floorId > buildingId > venueId.
	 * @param paramObject
	 */
	searchCategories(paramObject: {
		venueId?: string;
		buildingId?: string;
		floorId?: string;
	}): AxiosPromise<IResponse<IPoiCategory[]>>;
	/**
	 * @description Search orientation and poi.
	 * BuildingId, floorId and ordinal are mutually exclusive, priority: ordinal > floorId > buildingId.
	 * @param paramObj
	 */
	searchOrientation(paramObj: {
		/**
		 * User's current position, [lon, lat].
		 */
		center: [
			number,
			number
		];
		/**
		 * The angle between cellphone's orientation and the north.
		 */
		angle: number;
		/**
		 * Radius.
		 */
		distance: number;
		buildingId?: string;
		floorId?: string;
		/**
		 * Floor order in physical space, e.g. '-1', '0'(ground floor), '1'...
		 */
		ordinal?: string;
		/**
		 * Search type.
		 */
		distanceSearchType?: DistanceSearchType;
	}): AxiosPromise<IResponse<IOrientationPoi[]>>;
	private _changedRes;
}
export interface IResponseRoute {
	infos: IRouteInfo | null;
	paths: IRoutePath[];
}
export interface IRouteInfo {
	copyrights: string[];
	took: number;
}
export interface IInstruction {
	building_id: string;
	distance: number;
	floor_id: string;
	heading: number;
	interval: [
		number,
		number
	];
	ordinal: number;
	sign: number;
	street_name: string;
	text: string;
	time: number;
	type: string | null;
	venue_id: string;
}
export interface IRoutePath {
	bbox: [
		number,
		number,
		number,
		number
	];
	distance: number;
	instructions: IInstruction[];
	points: {
		coordinates: Array<[
			number,
			number
		]>;
		type: string;
	};
	snapped_waypoints: {
		coordinates: Array<[
			number,
			number
		]>;
		type: string;
	};
	time: number;
}
export declare enum WayFindingVehicleType {
	FOOT = "foot",
	WHEELCHAIR = "wheelchair",
	ESCALATOR = "escalator"
}
export declare class RouteService {
	private _api;
	private _request;
	constructor();
	/**
	 * @description Search the route of any two points.
	 * @param fromCoordinate Coordinate [lng, lat] of start point.
	 * @param toCoordinate Coordinate [lng, lat] of end point.
	 * @param fromFloorId {string | null}
	 * @param toFloorId {string | null}
	 * @param fromBuildingId {string | null}
	 * @param toBuildingId {string | null}
	 * @param vehicle
	 * @param locale Language-specific response.
	 * @param toDoor Whether the end point of the route is in the room(otherwise at the door), default is "true".
	 */
	search(fromCoordinate: [
		number,
		number
	], toCoordinate: [
		number,
		number
	], fromFloorId: string | null, toFloorId: string | null, fromBuildingId: string | null, toBuildingId: string | null, vehicle?: WayFindingVehicleType, locale?: string, toDoor?: boolean): AxiosPromise<IResponse<IResponseRoute>>;
}
export declare class RoutePainter {
	private readonly _maplibreMap;
	private _fromCoordinate;
	private _toCoordinate;
	private _fromMarkerIcon;
	private _toMarkerIcon;
	private _markerIconSize;
	private _paintProperties;
	constructor(maplibreMap: MaplibreMap);
	/**
	 * @description Set image of the start marker. This method must be called after map style loaded.
	 * This method must be called after map style loaded if you set an external URL.
	 * @param icon Sprite name in map style or the image url, png format.
	 * @param callback Called when the image(from an external URL) has loaded
	 * or with an error argument if there is an error.
	 */
	setFromMarkerIcon(icon: string, callback?: VoidFunction): void;
	/**
	 * @description Set image of the end marker. This method must be called after map style loaded.
	 * This method must be called after map style loaded if you set an external URL.
	 * @param icon Sprite name in map style or the image url, png format.
	 * @param callback Called when the image(from an external URL) has loaded
	 * or with an error argument if there is an error.
	 */
	setToMarkerIcon(icon: string, callback?: VoidFunction): void;
	/**
	 * @description Set image icon scale.
	 * @param size Default is 1.
	 */
	setMarkerIconSize(size: number): this;
	/**
	 * @description Set the route color of the indoor part.
	 * @param color The color type is a color in the sRGB color space.
	 * Formats: HTML-style hex values, RGB, RGBA, HSL, and HSLA.
	 * Predefined HTML colors names, like yellow and blue, are also permitted.
	 */
	setIndoorLineColor(color: string): this;
	/**
	 * @description Set the route color of the outdoor part.
	 * @param color The color type is a color in the sRGB color space.
	 * Formats: HTML-style hex values, RGB, RGBA, HSL, and HSLA.
	 * Predefined HTML colors names, like yellow and blue, are also permitted.
	 */
	setOutdoorLineColor(color: string): this;
	/**
	 * @description Set color of dashed lines which connected the start and end markers.
	 * @param color The color type is a color in the sRGB color space.
	 * Formats: HTML-style hex values, RGB, RGBA, HSL, and HSLA.
	 * Predefined HTML colors names, like yellow and blue, are also permitted.
	 */
	setDashedLineColor(color: string): this;
	/**
	 * @description Set color of shuttle bus line.
	 * @param color The color type is a color in the sRGB color space.
	 * Formats: HTML-style hex values, RGB, RGBA, HSL, and HSLA.
	 * Predefined HTML colors names, like yellow and blue, are also permitted.
	 */
	setBusLineColor(color: string): this;
	/**
	 * @description Render route on the map.
	 * @param path Route path from RouteService.search response.
	 * @param fromCoordinate Coordinate [lng, lat] of start point.
	 * @param toCoordinate Coordinate [lng, lat] of end point.
	 */
	render(path: IRoutePath, fromCoordinate: [
		number,
		number
	], toCoordinate: [
		number,
		number
	]): void;
	/**
	 * @description Remove route from the map.
	 */
	remove(): void;
	/**
	 * @description Filter paths' opacity by venue and ordinal.
	 * @param venueId {string | null | undefined}
	 * @param ordinal {string | null | undefined}
	 */
	setFilterByVenue(venueId: string | null | undefined, ordinal: string | null | undefined): void;
	/**
	 * @description Filter paths' opacity by building and ordinal.
	 * @param buildingId {string | null | undefined}
	 * @param ordinal {string | null | undefined}
	 */
	setFilterByBuilding(buildingId: string | null | undefined, ordinal: string | null | undefined): void;
	private _classifyFeatures;
	private _createLineFeature;
	private _createIconFeature;
	private _renderSolidLines;
	private _renderDashedLines;
	private _renderConnectors;
	private _renderFromToMarkers;
	private _addCollectionSource;
	private _addLineLayer;
	private _addTriangleLayer;
	private _addIconLayer;
}
export declare const OFFSET: number;
export declare const PAGE: number;
export declare const version: string;
export type { ControlPosition, Map as MaplibreMap, MapLayerEventType, FilterSpecification, PointLike, } from "maplibre-gl";

export {};
